"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable guard-for-in */
/* eslint-disable no-restricted-syntax */
const dedent_1 = __importDefault(require("dedent"));
const jobIndex_1 = __importDefault(require("./jobIndex"));
var CCIColour;
(function (CCIColour) {
    CCIColour["GREEN"] = "#42c88a";
    CCIColour["PURPLE"] = "#d8c4ea";
})(CCIColour || (CCIColour = {}));
const draw = (workflowName, print, jobs) => {
    const jobIndex = new jobIndex_1.default(jobs);
    const output = [];
    const appendOutput = (string) => {
        output.push(string);
    };
    appendOutput(` ${workflowName} {`);
    appendOutput(
    // eslint-disable-next-line prefer-template
    "  " +
        dedent_1.default(`
        ${workflowName} [
            style="filled"
            fillcolor="${CCIColour.GREEN}"
          ]`));
    const jobNames = jobIndex.getAllJobNames();
    for (const jobCount in jobNames) {
        const job = jobIndex.getJob(jobNames[jobCount]);
        const [thisJobName, jobAttrs] = [job.name, job.attrs];
        const { requires } = jobAttrs; // the list of upstream jobs
        if (requires) {
            for (const requirementCount in requires) {
                const upstreamJob = requires[requirementCount]; // the upstream jobs
                const upstreamJobName = upstreamJob.name;
                appendOutput(`  "${upstreamJobName}" -> "${thisJobName}";`);
            }
        }
        else {
            appendOutput(`  ${workflowName} -> "${thisJobName}";`);
        }
        // eslint-disable-next-line dot-notation
        if ("type" in jobAttrs && jobAttrs["type"] === "approval") {
            appendOutput(`  "${thisJobName}" [ style="filled" fillcolor="${CCIColour.PURPLE}" ];`);
        }
    }
    appendOutput("}");
    const rawOutput = output.join("\n");
    if (print) {
        console.log(`digraph${rawOutput}`);
    }
    else {
        console.log(`https://dreampuf.github.io/GraphvizOnline/#digraph${encodeURIComponent(rawOutput)}`);
    }
};
exports.default = draw;
//# sourceMappingURL=draw.js.map