#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* istanbul ignore file */
const fs_1 = __importDefault(require("fs"));
const yaml_1 = __importDefault(require("yaml"));
// import getWorkflowFromFile from "./getWorkflowsFromFile";
const parseCommandLine_1 = __importDefault(require("./parseCommandLine"));
const draw_1 = __importDefault(require("./draw"));
if (require.main !== module) {
    // caller is trying to require / import this module
    throw new Error("ccigraph is not a library");
}
const getWorkflowsFromFile = (filename) => {
    const fileData = fs_1.default.readFileSync(filename, "utf8");
    let circleciConfig;
    try {
        circleciConfig = yaml_1.default.parse(fileData);
    }
    catch (e) {
        throw new Error(`error while parsing YAML: ${e.message}`);
    }
    return circleciConfig.workflows;
};
const main = () => {
    const parsedArgs = parseCommandLine_1.default();
    const workflows = getWorkflowsFromFile(parsedArgs.file);
    if (parsedArgs.command === "list") {
        console.log(Object.keys(workflows).join("\n"));
        process.exit(0);
    }
    // must be draw command
    const workflowObject = workflows[parsedArgs.workflow];
    if (!workflowObject) {
        console.error(`ERROR: can't find workflow '${parsedArgs.workflow}' in file`);
        process.exit(1);
    }
    const { jobs } = workflowObject;
    draw_1.default(parsedArgs.workflow, parsedArgs.print, jobs);
};
try {
    main();
}
catch (e) {
    console.error(e.message);
}
//# sourceMappingURL=index.js.map