"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const job_1 = __importDefault(require("./job"));
class JobIndex {
    constructor(rawJobList) {
        this.jobIndex = {};
        this._indexAllRawJobs(rawJobList);
        this._normaliseAllRequiresLists();
        this._renameDuplicates();
    }
    _indexAllRawJobs(rawJobList) {
        for (let i = 0; i < rawJobList.length; i += 1) {
            const rawJob = rawJobList[i];
            const newJob = new job_1.default(rawJob);
            this._addJob(newJob);
        }
    }
    _normaliseAllRequiresLists() {
        // Replaces all strings in all requires lists with jobRefs.
        // If a requires values does not refer to exactly ONE job, raise an error.
        // for all jobs
        const jobNameList = this.getAllJobNames();
        for (let jobi = 0; jobi < jobNameList.length; jobi += 1) {
            const jobName = jobNameList[jobi];
            const job = this.getJob(jobName);
            // eslint-disable-next-line no-continue
            if (!("requires" in job.attrs))
                continue;
            const requirementsList = job.attrs.requires;
            for (let i = 0; i < requirementsList.length; i += 1) {
                const requiredJobName = requirementsList[i];
                const jobList = this.getJobsWithName(requiredJobName);
                if (jobList.length !== 1) {
                    throw new Error(`Error: Job '${job.name}' requires '${requiredJobName}', which is the name of ${jobList.length} other jobs in workflow`);
                }
                [requirementsList[i]] = jobList; // there is only one
            }
        }
    }
    _renameDuplicates() {
        let jobsWereRenamed;
        do {
            jobsWereRenamed = false;
            const jobNameList = this.getAllJobNames();
            for (let i = 0; i < jobNameList.length; i += 1) {
                const jobName = jobNameList[i];
                const jobList = this.getJobsWithName(jobName);
                if (jobList.length > 1) {
                    // there are duplicates, add increasing suffix to each job name
                    for (let jobCount = 0; jobCount < jobList.length; jobCount += 1) {
                        const job = jobList[jobCount];
                        const suffix = Number(jobCount) + 1;
                        job.name = `${jobName}-${suffix}`;
                        this._addJob(job);
                    }
                    delete this.jobIndex[jobName];
                    jobsWereRenamed = true;
                }
            }
        } while (jobsWereRenamed);
    }
    _addJob(job) {
        if (job.name in this.jobIndex) {
            this.jobIndex[job.name].push(job);
        }
        else {
            this.jobIndex[job.name] = [job];
        }
    }
    getJobsWithName(jobName) {
        if (jobName in this.jobIndex) {
            return this.jobIndex[jobName];
        }
        return [];
    }
    getJob(jobName) {
        return this.jobIndex[jobName][0];
    }
    getAllJobNames() {
        return Object.keys(this.jobIndex);
    }
}
exports.default = JobIndex;
//# sourceMappingURL=jobIndex.js.map